pub async fn parse_date_naive(date: String) -> Result<String>
Function to validate the user has supplied the date in the correct format and that the date is a valid calender date. Will exit the application of the date format is wrong or invalid.