pub struct RestClient {
    pub url: String,
    pub auth_token: String,
    pub client: Client,
}
Struct type that provides options for our implementation of a reqwest client.

Fields

url: Stringauth_token: Stringclient: Client

Implementations

source

impl RestClient

Implementation of our client to interact with the Amber REST API endpoints.

source

pub fn new_client(url: String, auth_token: String) -> Self

source

pub async fn get_site_data(&mut self) -> Result<Vec<SiteDetails>, Error>

RestClient function to request data from the Amber “/sites” endpoint.

source

pub async fn get_price_data(&mut self) -> Result<Vec<PriceData>>

RestClient function to request data from the Amber “/prices” endpoint.

source

pub async fn get_usage_data(&mut self) -> Result<Vec<UsageData>>

RestClient function to request data from the Amber “/usage” endpoint.

source

pub async fn get_renewables_data(&self) -> Result<Vec<RenewablesData>>

RustClient function to request data from the Amber “/renewables” endpoint.